package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmMaintenanceCompletionStatistics;

/**
 * 线路检修完成情况Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-03
 */
public interface PdmMaintenanceCompletionStatisticsMapper 
{
    /**
     * 查询线路检修完成情况
     * 
     * @param eventNo 线路检修完成情况主键
     * @return 线路检修完成情况
     */
    public PdmMaintenanceCompletionStatistics selectPdmMaintenanceCompletionStatisticsByEventNo(String eventNo);

    /**
     * 查询线路检修完成情况列表
     * 
     * @param pdmMaintenanceCompletionStatistics 线路检修完成情况
     * @return 线路检修完成情况集合
     */
    public List<PdmMaintenanceCompletionStatistics> selectPdmMaintenanceCompletionStatisticsList(PdmMaintenanceCompletionStatistics pdmMaintenanceCompletionStatistics);

    /**
     * 新增线路检修完成情况
     * 
     * @param pdmMaintenanceCompletionStatistics 线路检修完成情况
     * @return 结果
     */
    public int insertPdmMaintenanceCompletionStatistics(PdmMaintenanceCompletionStatistics pdmMaintenanceCompletionStatistics);

    /**
     * 修改线路检修完成情况
     * 
     * @param pdmMaintenanceCompletionStatistics 线路检修完成情况
     * @return 结果
     */
    public int updatePdmMaintenanceCompletionStatistics(PdmMaintenanceCompletionStatistics pdmMaintenanceCompletionStatistics);

    /**
     * 删除线路检修完成情况
     * 
     * @param eventNo 线路检修完成情况主键
     * @return 结果
     */
    public int deletePdmMaintenanceCompletionStatisticsByEventNo(String eventNo);

    /**
     * 批量删除线路检修完成情况
     * 
     * @param eventNos 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmMaintenanceCompletionStatisticsByEventNos(String[] eventNos);
}
